// This script can also be found in Google Earth Engine at:
// https://code.earthengine.google.com/8bf5d7743b2a045808a7adb51f836b57

var tc = ee.ImageCollection("IDAHO_EPSCOR/TERRACLIMATE"),
    ggb = ee.FeatureCollection("users/mkoontz/ggb-species-herbaria-records");

var precip = tc
.filterDate('1961-01-01', '1990-12-31') // filter TerraClimate to these dates
.select('pr')
.sum() // value is accumulated precip in a month in mm, so sum all the monthly values
.divide(30); // then divide by 30 years to get the mean annual precip

Map.addLayer(precip, {min: 0, max: 1000}, 'mean annual precip');

var july_max = tc
.filterDate('1961-01-01', '1990-12-31')
.filter(ee.Filter.calendarRange(7, 7, 'month')) // Filter to just July
.select('tmmx')
.mean() // single monthly value (and 30 of them; 1 per year), so taking the mean is fine
.multiply(0.1); // data are orginally multiplied by 10 to make them integers, so multiply by 0.1

Map.addLayer(july_max, {min: 20, max: 35}, 'july maximum');

var jan_min = tc
.filterDate('1961-01-01', '1990-12-31')
.filter(ee.Filter.calendarRange(1, 1, 'month')) // Filter to just January
.select('tmmn')
.mean()
.multiply(0.1); // data are orginally multiplied by 10 to make them integers, so multiply by 0.1

Map.addLayer(jan_min, {min: -10, max: 5}, "jan minimum");

var cwd = tc
.filterDate('1961-01-01', '1990-12-31')
.select('def') // this is what the climatic water deficit layer is called
.sum() // same as precip, it's a cumulative measure, so sum and divide by 30 years
.divide(30)
.multiply(0.1); // data are orginally multiplied by 10 to make them integers, so multiply by 0.1

Map.addLayer(cwd, {min: 0, max: 1500}, "cwd");

// Make a multiband raster of the 4 different climate layers
var climate_vars =
precip.addBands(july_max).addBands(jan_min).addBands(cwd);

// Extract the pixel value for the 4 climate layers using nearest neighbor interpolation 
// at each herbaria record geolocation
var ggb_climate_niches = climate_vars.reduceRegions(ggb, ee.Reducer.first(), 4000);

// Export as a csv
Export.table.toDrive(ggb_climate_niches, 'ggb-climate-niches', 'ee', 'ggb-climate-niches_terraclimate_1961-1990');

Map.addLayer(ggb);