# load libraries
library(tidyverse)
library(gridExtra)
library(cowplot)

# Read in lat/lon data for White Mountain summits and downslope surveys along with climate data
# Climate data are 30-year means from 1951-1980, climateWNA v 5.51
dat=read_csv("data/data_raw/downslope_coords_Normal_1961_1990MSY.csv") %>%
  mutate(ID1=factor(ID1),ID2=factor(ID2)) %>%
  rename(Summit=ID1)

head(dat)

CMD=ggplot(dat, aes(x=Elevation, y=CMD)) + 
  geom_point(aes(color = Summit), size=2) +
  scale_color_viridis_d() +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  labs(x = NULL, 
       y = expression(CMD~(mm)))+
  theme_bw()+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))
  
MAP=ggplot(dat, aes(x=Elevation, y=MAP)) + 
  geom_point(aes(color = Summit), size=2) +
  scale_color_viridis_d() +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  labs(x = NULL,
       y = expression(MAP~(mm)))+
  theme_bw()+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))

July_max=ggplot(dat, aes(x=Elevation, y=Tmax07)) + 
  geom_point(aes(color = Summit), size=2) + 
  scale_color_viridis_d() +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  labs(x = NULL,
       y = expression(July~T[max]~"(?C)"))+
  theme_bw()+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))
  
Jan_min=ggplot(dat, aes(x=Elevation, y=Tmin01)) + 
  geom_point(aes(color = Summit), size=2) +
  scale_color_viridis_d() +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  labs(x = NULL,
       y = expression(Jan~T[min]~"(?C)"))+
  theme_bw()+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))
  


shared_legend <- cowplot::get_legend(CMD + theme(legend.direction = "vertical", legend.justification="center" ,legend.box.just = "bottom"))

panel_plot_just_figures <- cowplot::plot_grid(CMD + theme(legend.position = "none"), 
                                              MAP + theme(legend.position = "none"),
                                              July_max + theme(legend.position = "none"),
                                              Jan_min + theme(legend.position = "none"),
                                              ncol = 2, nrow = 2, labels = LETTERS[1:4])

panel_plot_with_legend <- cowplot::plot_grid(panel_plot_just_figures, 
                                             shared_legend,
                                             ncol = 2, rel_widths = c(1, 0.1))

panel_plot_with_xlab <- add_sub(panel_plot_with_legend, "Elevation(m)", size=16)
ggdraw(panel_plot_with_xlab)

ggsave(filename = "figures/downslope_clim_WNA.pdf", plot = panel_plot_with_xlab, width=7.25, units="in")
